summaryrefslogtreecommitdiffstats
path: root/chrome/plugin/plugin_main.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/plugin/plugin_main.cc')
-rw-r--r--chrome/plugin/plugin_main.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/plugin/plugin_main.cc b/chrome/plugin/plugin_main.cc
index b925a01..94f50bc 100644
--- a/chrome/plugin/plugin_main.cc
+++ b/chrome/plugin/plugin_main.cc
@@ -32,11 +32,11 @@ int PluginMain(CommandLine &parsed_command_line,
bool no_sandbox = parsed_command_line.HasSwitch(switches::kNoSandbox) ||
!parsed_command_line.HasSwitch(switches::kSafePlugins);
if (target_services && !no_sandbox) {
// The command line might specify a test dll to load.
if (parsed_command_line.HasSwitch(switches::kTestSandbox)) {
- std::wstring test_dll_name =
+ std::wstring test_plugin_name =
parsed_command_line.GetSwitchValue(switches::kTestSandbox);
- sandbox_test_module = LoadLibrary(test_dll_name.c_str());
+ sandbox_test_module = LoadLibrary(test_plugin_name.c_str());
DCHECK(sandbox_test_module);
}
}
@@ -32,11 +32,11 @@ int PluginMain(CommandLine &parsed_command_line,
!parsed_command_line.HasSwitch(switches::kSafePlugins);
if (target_services && !no_sandbox) {
- // The command line might specify a test dll to load.
+ // The command line might specify a test plugin to load.
if (parsed_command_line.HasSwitch(switches::kTestSandbox)) {